@@ -1,9 +1,10 @@
 package WordList;
 
 our $DATE = '2018-02-20'; # DATE
-our $VERSION = '0.1.4'; # VERSION
+our $VERSION = '0.1.5'; # VERSION
 
-use base 'WordListC';
+our @ISA = qw(WordListC);
+use WordListC ();
 
 # TODO: binary search method, etc
 
@@ -22,7 +23,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.1.4 of WordList (from Perl distribution WordList), released on 2018-02-20.
+This document describes version 0.1.5 of WordList (from Perl distribution WordList), released on 2018-02-20.
 
 =head1 SYNOPSIS
 
